@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2016-08-23'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2017-01-07'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,10 @@ use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(detect_perinci_cmdline_script);
+our @EXPORT_OK = qw(
+                       detect_pericmd_script
+                       detect_perinci_cmdline_script
+               );
 
 our %SPEC;
 
@@ -18,7 +21,7 @@ $SPEC{':package'} = {
     summary => 'Utility routines related to Perinci::CmdLine',
 };
 
-$SPEC{detect_perinci_cmdline_script} = {
+$SPEC{detect_pericmd_script} = {
     v => 1.1,
     summary => 'Detect whether a file is a Perinci::CmdLine-based CLI script',
     description => <<'_',
@@ -66,7 +69,7 @@ _
         },
     },
 };
-sub detect_perinci_cmdline_script {
+sub detect_pericmd_script {
     my %args = @_;
 
     (defined($args{filename}) xor defined($args{string}))
@@ -186,6 +189,12 @@ sub detect_perinci_cmdline_script {
     [200, "OK", $yesno, $meta];
 }
 
+{
+    no strict 'refs';
+    # old name, deprecated
+    *detect_perinci_cmdline_script = \&detect_pericmd_script;
+}
+
 1;
 # ABSTRACT: Utility routines related to Perinci::CmdLine
 
@@ -201,7 +210,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.11 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2016-08-23.
+This document describes version 0.12 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2017-01-07.
 
 =head1 SYNOPSIS
 
@@ -210,7 +219,7 @@ This document describes version 0.11 of Perinci::CmdLine::Util (from Perl distri
 =head1 FUNCTIONS
 
 
-=head2 detect_perinci_cmdline_script(%args) -> [status, msg, result, meta]
+=head2 detect_pericmd_script(%args) -> [status, msg, result, meta]
 
 Detect whether a file is a Perinci::CmdLine-based CLI script.
 
@@ -265,7 +274,7 @@ that contains extra information.
 
 Return value:  (any)
 
-=for Pod::Coverage ^()$
+=for Pod::Coverage ^(detect_perinci_cmdline_script)$
 
 =head1 HOMEPAGE
 
@@ -293,7 +302,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
